@@ -18,6 +18,7 @@
 # - Vincent Garonne <vgaronne@gmail.com>, 2014-2018
 # - Ralph Vigne <ralph.vigne@cern.ch>, 2015
 # - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2019
+# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
 #
 # PY3K COMPATIBLE
 
@@ -41,9 +42,9 @@ class AccountLimitClient(BaseClient):
     ACCOUNTLIMIT_BASEURL = 'accountlimits'
 
     def __init__(self, rucio_host=None, auth_host=None, account=None, ca_cert=None,
-                 auth_type=None, creds=None, timeout=600, user_agent='rucio-clients'):
+                 auth_type=None, creds=None, timeout=600, user_agent='rucio-clients', vo=None):
         super(AccountLimitClient, self).__init__(rucio_host, auth_host, account, ca_cert,
-                                                 auth_type, creds, timeout, user_agent)
+                                                 auth_type, creds, timeout, user_agent, vo=vo)
 
     def set_account_limit(self, account, rse, bytes, locality):
         """
